@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import IO, Any, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -515,7 +515,7 @@ GetMetricStatisticsOutputTypeDef = TypedDict(
 
 GetMetricWidgetImageOutputTypeDef = TypedDict(
     "GetMetricWidgetImageOutputTypeDef",
-    {"MetricWidgetImage": bytes, "ResponseMetadata": "ResponseMetadata"},
+    {"MetricWidgetImage": Union[bytes, IO[bytes]], "ResponseMetadata": "ResponseMetadata"},
     total=False,
 )
 
